@@ -294,6 +294,25 @@ public class FormatData_ka extends ListResourceBundle {
             { "roc.AmPmMarkers", metaValue_roc_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "short.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0\u00a0\u10d0\u10d7'.'",
+                    "00\u00a0\u10d0\u10d7'.'",
+                    "000\u00a0\u10d0\u10d7'.'",
+                    "0\u00a0\u10db\u10da\u10dc'.'",
+                    "00\u00a0\u10db\u10da\u10dc'.'",
+                    "000\u00a0\u10db\u10da\u10dc'.'",
+                    "0\u00a0\u10db\u10da\u10e0\u10d3'.'",
+                    "00\u00a0\u10db\u10da\u10e0\u10d3'.'",
+                    "000\u00a0\u10db\u10da\u10e0'.'",
+                    "0\u00a0\u10e2\u10e0\u10da'.'",
+                    "00\u00a0\u10e2\u10e0\u10da'.'",
+                    "000\u00a0\u10e2\u10e0\u10da'.'",
+                }
+            },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
             { "timezone.regionFormat.daylight", "{0} \u10d6\u10d0\u10e4\u10ee\u10e3\u10da\u10d8\u10e1 \u10d3\u10e0\u10dd" },
             { "DatePatterns",
@@ -315,6 +334,25 @@ public class FormatData_ka extends ListResourceBundle {
             { "standalone.MonthNames", metaValue_MonthNames },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "timezone.regionFormat", "\u10d3\u10e0\u10dd: {0}" },
+            { "long.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0 \u10d0\u10d7\u10d0\u10e1\u10d8",
+                    "00 \u10d0\u10d7\u10d0\u10e1\u10d8",
+                    "000 \u10d0\u10d7\u10d0\u10e1\u10d8",
+                    "0 \u10db\u10d8\u10da\u10d8\u10dd\u10dc\u10d8",
+                    "00 \u10db\u10d8\u10da\u10d8\u10dd\u10dc\u10d8",
+                    "000 \u10db\u10d8\u10da\u10d8\u10dd\u10dc\u10d8",
+                    "0 \u10db\u10d8\u10da\u10d8\u10d0\u10e0\u10d3\u10d8",
+                    "00 \u10db\u10d8\u10da\u10d8\u10d0\u10e0\u10d3\u10d8",
+                    "000 \u10db\u10d8\u10da\u10d8\u10d0\u10e0\u10d3\u10d8",
+                    "0 \u10e2\u10e0\u10d8\u10da\u10d8\u10dd\u10dc\u10d8",
+                    "00 \u10e2\u10e0\u10d8\u10da\u10d8\u10dd\u10dc\u10d8",
+                    "000 \u10e2\u10e0\u10d8\u10da\u10d8\u10dd\u10dc\u10d8",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
